Bayesian Filtering and Smoothing
================================

Bayesian filtering and smoothing provides a framework for efficient inference in state space models.
For non-linear state space components, ProbNum provides linearization techniques that enables
Gaussian filtering and smoothing in more complex dynamical systems.

See the notebooks below to learn more about how to use ProbNum's functionality for Bayesian filtering and smoothing.


.. nbgallery::
   :maxdepth: 2

   filtsmooth/linear_gaussian_filtering_smoothing
   filtsmooth/nonlinear_gaussian_filtering_smoothing
   filtsmooth/particle_filtering

----

You can also interactively try out the |Tutorials| directly in the browser or
by downloading the notebooks from the
`GitHub repository <https://github.com/probabilistic-numerics/probnum/tree/master/docs/source/tutorials>`_.

.. |Tutorials| image:: https://img.shields.io/badge/Tutorials-Jupyter-579ACA.svg?&logo=Jupyter&logoColor=white
    :target: https://mybinder.org/v2/gh/probabilistic-numerics/probnum/master?filepath=docs%2Fsource%2Ftutorials
    :alt: ProbNum's Tutorials
